Dialog Example
===============================================================================

:download:`dialog.enaml <../../../examples/containers/dialog.enaml>`

.. literalinclude:: ../../../examples/containers/dialog.enaml
    :language: python

::

 $ enaml-run dialog.enaml

.. image:: images/dialog0.png

.. image:: images/dialog1.png

.. image:: images/dialog2.png
